Version History
***************

Version 1.2
===========

* Change name to linaro-json
* Add dependency on versiontools
* Register on pypi
* Add ReST documentation


Version 1.1
===========

* Add support for retrieving default values from the schema


Version 1.0
===========

* Initial release
